@@ -6,7 +6,7 @@ require DynaLoader;
 require Exporter;
 use MIME::Base64 qw(encode_base64);
 use vars qw(@ISA $VERSION @EXPORT_OK);
-$VERSION = '0.11';
+$VERSION = '0.12';
 @ISA = qw(DynaLoader Exporter);
 
 
@@ -125,9 +125,28 @@ Set the body of the next request via http_call().
 
   my $rc = http_call("GET", "http://localhost");
 
-Do an http request.  Returns either 0 or 1 depending on whether the call was 
+Do an http request.  Returns either < 0 or 1 depending on whether the call was 
 successful - remember to still check the http_status() code though.
 
+Value < 0 are:
+        -1 : an invalid action (HTTP verb) was supplied
+        -2 : must supply an action (HTTP verb)
+        -3 : must supply a url
+        -4 : url must start with http:// or https://
+        -5 : write of headers to socket failed
+        -6 : write of data to socket was short
+        -7 : failed to write last line to socket
+        -8 : something wrong with the Conent-Length header
+       -11 : SSL_CTX_new failed - abort everything
+       -12 : SSL_new failed - abort everything
+       -13 : SSL_connect failed - abort everything
+       -14 : SSL_get_peer_certificate failed - abort everything
+       -15 : X509_get_subject_name failed - abort everything
+       -16 : X509_get_issuer_name failed - abort everything
+       -17 : cant find the next chunk for Transfer-encoding
+       -18 : cant find end headers
+       -19 : You must supply a Host header for HTTP/1.1
+
 
 =head2 http_status()
 
